@@ -16,11 +16,11 @@ def string_to_float(string):
     return float(string)
 
 def np_arr_to_dict(arr):
-    return {'str': np.ndarray.tostring(arr),
+    return {'str': np.ndarray.tostring(arr).decode('utf-8'),
         'shape':list(arr.shape),
         'dtype':str(arr.dtype)
     }
 
 def dict_to_np_arr(data):
-    arr, shape, dtype = data['str'], data['shape'], data['dtype']
+    arr, shape, dtype = data['str'].encode('utf-8'), data['shape'], data['dtype']
     return np.fromstring(arr, dtype=dtype).reshape(tuple(shape))
\ No newline at end of file
